import os  # Importing the os module for file and directory operations
from cryptography.fernet import Fernet  # Importing Fernet class for symmetric encryption

# Function to encrypt a file
def encrypt_file(file_path, key):
    # Reading the data from the file
    with open(file_path, 'rb') as file:
        file_data = file.read()

    fernet = Fernet(key)  # Initializing Fernet with the provided key
    encrypted_data = fernet.encrypt(file_data)  # Encrypting the data

    # Creating the path for the encrypted file
    encrypted_file_path = file_path + '.encrypted'

    # Writing the encrypted data to a new file
    with open(encrypted_file_path, 'wb') as encrypted_file:
        encrypted_file.write(encrypted_data)

    # Removing the original file after encryption
    os.remove(file_path)
    return encrypted_file_path

# Function to encrypt all files in a folder
def encrypt_folder(folder_path, key):
    encrypted_files = []  # List to store paths of encrypted files

    # Walking through all files in the folder
    for root, dirs, files in os.walk(folder_path):
        for file in files:
            # Constructing the full path for each file
            file_path = os.path.join(root, file)
            encrypted_file_path = encrypt_file(file_path, key)  # Encrypting each file
            encrypted_files.append(encrypted_file_path)  # Storing the path of the encrypted file

    return encrypted_files

# Main function to handle the encryption process
def main(folder_path):
    key = Fernet.generate_key()  # Generating a new encryption key
    print(f'Encryption Key: {key.decode()}')

    encrypted_files = encrypt_folder(folder_path, key)  # Encrypting the folder

    # Printing the paths of encrypted files
    for encrypted_file in encrypted_files:
        print(f'File encrypted to: {encrypted_file}')

    return encrypted_files, key

# Path to the folder containing files to be encrypted
folder_path = r'Sample'
# Encrypting the folder and getting the paths of encrypted files and the encryption key
encrypted_files, key = main(folder_path)